@@ -24,20 +24,22 @@ include/global.h - Shared definitions for user-space apps
 #ifndef TTYRPLD_GLOBAL_H
 #define TTYRPLD_GLOBAL_H 1
 
-#include <endian.h>
+#include <sys/types.h>
 #include <stdint.h>
 
+#    include <endian.h>
+#    if __BYTE_ORDER == __BIG_ENDIAN
+#        define SWAB(ptr, sz) swab_be((ptr), (sz))
+#    else
+#        define SWAB(ptr, sz)
+#    endif
+
 #ifndef O_BINARY
 #    define O_BINARY 0
 #endif
-#if __BYTE_ORDER == __BIG_ENDIAN
-#    define PP_swab(ptr, sz) swab_be((ptr), (sz))
-#else
-#    define PP_swab(ptr, sz)
-#endif
 
 #define MAXFNLEN 256
-#define TTYRPLD_VERSION "1.26"
+#define TTYRPLD_VERSION "1.31"
 
 extern int count_args(const char **);
 extern ssize_t read_wait(int, void *, size_t);
