@@ -24,9 +24,11 @@ include/rpl_ioctl.h - IOCTL numbers for RPLDEV
 #ifndef RPL_IOCTL_H
 #define RPL_IOCTL_H 1
 
-#ifdef __KERNEL__
+#if defined(__linux__) && defined(__KERNEL__)
 #    include <linux/ioctl.h>
-#else
+#    include <linux/types.h>
+#else // userspace
+#    include <sys/types.h>
 #    include <sys/ioctl.h>
 #endif
 
