@@ -24,11 +24,11 @@ include/rpl_packet.h - Packet definitions for RPLD and RPLDEV
 #ifndef RPL_PACKET_H
 #define RPL_PACKET_H 1
 
-#define PACKED __attribute__((packed))
+#define __PACKED __attribute__((packed))
 
-#ifdef __KERNEL__
+#if defined(__linux__) && defined(__KERNEL__)
 #    include <linux/types.h>
-#else
+#else // userspace
 #    include <stdint.h>
 #endif
 
@@ -47,24 +47,24 @@ enum {
 };
 
 struct rpld_packet {
-    uint32_t dev, dev2;
+    uint32_t dev;
     uint16_t size;
     uint8_t event, magic;
-} PACKED;
+} __PACKED;
 
 struct mem_packet {
-    uint32_t dev, dev2;
+    uint32_t dev;
     uint16_t size;
     uint8_t event, magic;
     struct timeval tv;
-} PACKED;
+} __PACKED;
 
 struct disk_packet {
     uint16_t size;
     uint8_t event, magic;
     struct timeval tv;
-} PACKED;
+} __PACKED;
 
-#endif /* RPL_PACKET_H */
+#endif // RPL_PACKET_H
 
 //==[ End of file ]============================================================
