@@ -105,10 +105,10 @@ static void *client_thread(void *arg) {
             break;
         } else if(req > IFT_int_min && req < IFT_int_max) {
             if(!RECEIVE_FULL(fd, &gint, sizeof(uint32_t))) { break; }
-            PP_swab(&gint, sizeof(uint32_t));
+            SWAB(&gint, sizeof(uint32_t));
         } /* else if(req > IFT_str_min && req < IFT_str_max) {
             if(!RECEIVE_FULL(fd, &gint, sizeof(uint32_t))) { break; }
-            PP_swab(&gint, sizeof(uint32_t));
+            SWAB(&gint, sizeof(uint32_t));
             if(!RECEIVE_FULL(fd, buf, min_uint(sizeof(buf), gint))) { break; }
         } */
 
@@ -141,7 +141,7 @@ static void *client_thread(void *arg) {
 
             // Other
             default:
-                notify(LOG_WARNING, "infod: Unknown request %d, closing"
+                notify(LOG_WARNING, "[infod] Unknown request %d, closing"
                  " connection to not run into conversion problems.\n", req);
                 goto clthr__exit;
         }
@@ -163,10 +163,9 @@ static void getinfo_text(uint32_t dev, int fd) {
         struct HXbtrav *travp;
 
         skprintf(fd,
-          "AC   DEVICE TTY      BYTES IN       OUT FILENAME\n"
           "==========================================================================\n"
-          "  [---,---] *       %9llu %9llu ttyrpld " TTYRPLD_VERSION "\n"
-          "            IOCD: %zu/%zu/%zu/%zu  RW: %zu/%zu  I: %zu  B: %zu\n"
+          "  *       %9llu %9llu ttyrpld " TTYRPLD_VERSION "\n"
+          "  IOCD: %zu/%zu/%zu/%zu  RW: %zu/%zu  I: %zu  B: %zu\n"
           "--------------------------------------------------------------------------\n",
           Stats.in, Stats.out, Stats.init, Stats.open, Stats.close,
           Stats.deinit, Stats.read, Stats.write, Stats.ioctl, Stats.badpack
@@ -297,8 +296,8 @@ static void print_entry_text(int fd, struct tty *tty) {
     }
 
     G_devname_nm(tty->dev, buf, sizeof(buf));
-    skprintf(fd, "%c [%3ld,%3ld] %-7s %9zu %9zu %s\n", status,
-      KD26_PARTS(tty->dev), buf, tty->in, tty->out,
+    skprintf(fd, "%c %-7s %9zu %9zu %s\n", status,
+      buf, tty->in, tty->out,
       basename_pp(tty->file, GOpt.ofmt)
     );
     return;
@@ -327,7 +326,7 @@ static int skprintf(int fd, const char *fmt, ...) {
 
     va_start(argp, fmt);
     le = s = vsnprintf(buf, sizeof(buf), fmt, argp);
-    PP_swab(&le, sizeof(size_t));
+    SWAB(&le, sizeof(size_t));
     send_wait(fd, &le, sizeof(uint32_t), 0);
     send_wait(fd, buf, s, 0);
 
