@@ -34,6 +34,9 @@ user/pctrl.c - "Remote control" for ttyreplay
 #include <string.h>
 #include <termios.h>
 #include <unistd.h>
+#ifndef SA_ONESHOT
+#    define SA_ONESHOT SA_RESETHAND
+#endif
 #include "pctrl.h"
 
 // Functions
