@@ -111,7 +111,7 @@ char *G_devname_nm(uint32_t dev, char *buf, size_t count) {
         }
     }
 
-    if(*buf == '\0') { snprintf(buf, count, "(%lu:%lu)", major, minor); }
+    if(*buf == '\0') { snprintf(buf, count, "[%lu:%lu]", major, minor); }
     return buf;
 }
 
