@@ -93,11 +93,12 @@ int main(int argc, const char **argv) {
 
     if(!get_options(&argc, &argv)) { return EXIT_FAILURE; }
 
+    fprintf(stderr, "> ttyreplay " TTYRPLD_VERSION "\n");
     fprintf(stderr,
-      "> ttyreplay " TTYRPLD_VERSION "\n"
-      "This program comes with ABSOLUTELY NO WARRANTY; it is free software\n"
-      "and you are welcome to redistribute it under certain conditions; for\n"
-      "details see the COPYING file which should have come with this program.\n"
+      "This program comes with ABSOLUTELY NO WARRANTY; it is free "
+      "software\n" "and you are welcome to redistribute it under certain "
+      "conditions; for\n" "details see the COPYING file which should have "
+      "come with this program.\n"
     );
 
     if(argc == 0) {
@@ -177,30 +178,30 @@ static int replay_file(int fd, const char *name) {
             continue;
         }
 
-        PP_swab(&packet.size, sizeof(packet.size));
-        PP_swab(&packet.tv.tv_sec, sizeof(packet.tv.tv_sec));
-        PP_swab(&packet.tv.tv_usec, sizeof(packet.tv.tv_usec));
+        SWAB(&packet.size, sizeof(packet.size));
+        SWAB(&packet.tv.tv_sec, sizeof(packet.tv.tv_sec));
+        SWAB(&packet.tv.tv_usec, sizeof(packet.tv.tv_usec));
 
         switch(packet.event) {
             case EVT_WRITE:
                 e_proc(fd, &packet, &ps, &tick, &stamp, &skew);
                 break;
             case EVT_IDENT:
-                fprintf(stderr, "\n\e[1;37m" "Created using ");
+                fprintf(stderr, "\n\e[1;37m%s ", "Created using"); // ]
                 read_through(fd, STDERR_FILENO, packet.size);
-                fprintf(stderr, "\e[0m\n");
+                fprintf(stderr, "\e[0m\n"); // ]
                 break;
             case EVT_DEINIT:
-                fprintf(stderr, "\n\e[1;37;41m"
-                 "<tty device has been closed>\e[0m\n");
+                fprintf(stderr, "\n\e[1;37;41m%s\e[0m\n", // ]]
+                 "<tty device has been closed>");
                 // fallthrough kinda
                 read_nullfm(fd, packet.size);
                 break;
             case EVT_READ:
                 if(ps.echo) {
-                    printf("\e[1;37;41m");
+                    printf("\e[1;37;41m"); // ]
                     e_proc(fd, &packet, &ps, &tick, &stamp, &skew);
-                    printf("\e[0m");
+                    printf("\e[0m"); // ]
                     break;
                 }
                 // true fallthrough
@@ -215,11 +216,13 @@ static int replay_file(int fd, const char *name) {
     pctrl_deactivate(0);
 
     if(eax < 0) {
-        perror("\n\e[1;37;41m" "<Error while reading from stream>\e[0m\n"
-         "read():");
+        fprintf(stderr, "\n\e[1;37;41m%s\e[0m\nread(): %s\n", // ]]
+         "<Error while reading from stream>", strerror(errno));
     }
 
-    printf("\n\e[1;37;41m" "<Log replaying of %s finished>\e[0m\n", name);
+    printf("\n\e[1;37;41m"); // ]
+    printf("<Log replaying of %s finished>", name);
+    printf("\e[0m\n"); // ]
     return ps.brk;
 }
 
@@ -276,11 +279,11 @@ static void e_proc(int fd, struct disk_packet *p, struct pctrl_info *i,
         time_t now = p->tv.tv_sec;
         localtime_r(&now, &tm);
         if(Opt.showtime == 1) {
-            strftime(buf, sizeof(buf), "\e7\e[1;300H\e[9D"
-             "\e[0;7m[\e[0;1;37;41m" "%H:%M:%S" "\e[0;7m]\e8", &tm);
+            strftime(buf, sizeof(buf), "\e7\e[1;300H\e[9D" // ]]
+             "\e[0;7m[\e[0;1;37;41m" "%H:%M:%S" "\e[0;7m]\e8", &tm); // ]]]
         } else {
-            strftime(buf, sizeof(buf), "\e7\e[1;300H\e[12D"
-             "\e[0;7m[\e[0;1;37;41m" "%d.%m %H:%M" "\e[0;7m]\e8", &tm);
+            strftime(buf, sizeof(buf), "\e7\e[1;300H\e[12D" // ]]
+             "\e[0;7m[\e[0;1;37;41m" "%d.%m %H:%M" "\e[0;7m]\e8", &tm); // ]]]
         }
         write(STDOUT_FILENO, buf, strlen(buf));
     }
@@ -420,8 +423,8 @@ static int get_options(int *argc, const char ***argv) {
         {NULL, 'F', POPT_ARG_NONE, NULL, 'F',
          "Live feed follow mode (like `tail -f`)", NULL},
         {NULL, 'J', POPT_ARG_STRING, &tmp, 'J',
-         "Seek to time relative to the start of the log"
-         " (HH:MM:SS or total SEC, see docs)", "tspec"},
+         "Seek to time position (HH:MM:SS or total SEC, "
+         "see docs)", "tspec"},
         {NULL, 'S', POPT_ARG_DOUBLE, &Opt.factor, '\0',
          "Speed factor (default: 1.0)", NULL},
         {NULL, 'T', POPT_ARG_NONE, &Opt.nodelay, 'T',
@@ -429,12 +432,11 @@ static int get_options(int *argc, const char ***argv) {
         {NULL, 'f', POPT_ARG_NONE, NULL, 'f',
          "Catch-up follow mode (play file, switch to live feed on EOF)", NULL},
         {NULL, 'j', POPT_ARG_LONG, &Opt.skval, 'j',
-         "Skip the given number of EV_WRITE packets", NULL},
+         "Skip the given number of EVT_WRITE packets", NULL},
         {NULL, 'm', POPT_ARG_LONG, &Opt.maxdelay, 'm',
          "Maximum delay to wait between packets", "msec"},
         {NULL, 't', POPT_ARG_NONE, NULL, 't',
-         "Show the timestamp at the bottom of the screen"
-         " (May not work with all terminals!)", NULL},
+         "Show the timestamp at the top of the screen", NULL},
         POPT_AUTOHELP
         POPT_TABLEEND
     };
@@ -589,6 +591,10 @@ static int usleep_ovcorr(struct timeval *req, long *skew) {
     (*) for i386/2.4: HZ=100, i.e. 10 ms (10000 µs)
         for  all/2.6: HZ=1000, i.e. 1 ms (1000 µs)
 
+    I do not claim that all 2.4 have HZ=100, especially since distributors
+    like to change such. Just as likely, someone may set HZ back to 100 for
+    a 2.6 one.
+
       >Therefore, nanosleep pauses always for at least the speci-
       >fied time, however it can take up to  10  ms  longer  than
       >specified  until  the  process becomes runnable again. [...]
