@@ -61,12 +61,16 @@ static int Sockfd = -1;
 //-----------------------------------------------------------------------------
 int rplctl_main(int argc, const char **argv) {
     if((Sockfd = unix_client(GOpt.infod_port)) < 0) {
-        fprintf(stderr, "connect() to %s failed: %s\n",
+        fprintf(stderr, "Connection to %s failed: %s\n",
          GOpt.infod_port, strerror(errno));
         return EXIT_FAILURE;
     }
 
     if(get_options(&argc, &argv) == 0) {
+        if(!Opt.parseable) {
+            printf("A %-3s %13s %9s %s\n", "TTY", "BYTES IN",
+             "OUT", "FILENAME");
+        }
         send_int(Sockfd, IFP_GETINFO_A, 0);
     }
 
@@ -110,7 +114,8 @@ static uint32_t getdev(const char *s) {
                 break;
             }
             if(errno != ENOENT) {
-                fprintf(stderr, "Cannot stat %s: %s\n", buf, strerror(errno));
+                fprintf(stderr, "Cannot stat %s: %s\n",
+                 buf, strerror(errno));
                 return 0;
             }
             ++dirp;
@@ -135,7 +140,7 @@ static void read_reply(int fd) {
         fd_set rd;
 
         recv(fd, &reply_size, sizeof(uint32_t), MSG_WAITALL);
-        PP_swab(&reply_size, sizeof(uint32_t));
+        SWAB(&reply_size, sizeof(uint32_t));
         if(reply_size == 0) { break; }
 
         while(reply_size > 0) {
@@ -155,7 +160,7 @@ static void read_reply(int fd) {
 
 static void send_int(int fd, unsigned char req, uint32_t dev) {
     send_wait(fd, &req, sizeof(unsigned char), 0);
-    PP_swab(&dev, sizeof(uint32_t));
+    SWAB(&dev, sizeof(uint32_t));
     send_wait(fd, &dev, sizeof(uint32_t), 0);
     read_reply(fd);
     return;
@@ -172,7 +177,7 @@ static void send_string(int fd, unsigned char req, const char *str) {
     size_t size = strlen(str);
     uint32_t szpack = size;
     send_wait(fd, &req, sizeof(unsigned char), 0);
-    PP_swab(&szpack, sizeof(uint32_t));
+    SWAB(&szpack, sizeof(uint32_t));
     send_wait(fd, &szpack, sizeof(uint32_t), 0);
     send_wait(fd, str, size, 0);
     read_reply(fd);
@@ -206,17 +211,17 @@ static int get_options(int *argc, const char ***argv) {
         {NULL, 'D', POPT_ARG_STRING, &tmp, 'D',
          "Ignore data from tty", "tty"},
         {NULL, 'L', POPT_ARG_STRING | POPT_ARGFLAG_OPTIONAL, &tmp, 'L',
-         "Explicitly request info about all [one] ttys", "tty"},
+         "Explicitly request info about all [or given] ttys", "tty"},
         {NULL, 'S', POPT_ARG_STRING, &tmp, 'S',
          "Ignore data from tty until next tty session", "tty"},
         {NULL, 'X', POPT_ARG_STRING, &tmp, 'X',
-         "Call log_close() for the given tty", "tty"},
+         "Close the tty's logfile", "tty"},
         {NULL, 'Z', POPT_ARG_STRING | POPT_ARGFLAG_OPTIONAL, &tmp, 'Z',
          "Zero all packet and byte counters", "tty"},
         {NULL, 'f', POPT_ARG_STRING, &GOpt.infod_port, 0,
          "Path to the INFOD socket", "file"},
         {NULL, 't', POPT_ARG_NONE, &Opt.parseable, 0,
-         "Generate sscanf() parseable output", NULL},
+         "Generate easy-parseable output", NULL},
         POPT_AUTOHELP
         POPT_TABLEEND
     };
