@@ -77,7 +77,7 @@ static int pconfig_user(const char *, unsigned char, void *, void *);
 inline static const char *basename(const char *);
 static char *getnamefromuid(uid_t, char *, size_t);
 static uid_t getuidfromname(const char *);
-static int value_cmp(void *, void *);
+inline static int value_cmp(void *, void *);
 
 // Global variables (begin with uppercase character)
 static void *Buffer = NULL;
@@ -122,11 +122,11 @@ int main(int argc, const char **argv) {
     memset(&Stats, 0, sizeof(Stats));
 
     if(GOpt.verbose) {
-        printf(
-          "# rpld " TTYRPLD_VERSION "\n"
-          "This program comes with ABSOLUTELY NO WARRANTY; it is free software\n"
-          "and you are welcome to redistribute it under certain conditions; for\n"
-          "details see the COPYING file which should have come with this program.\n"
+        printf("# rpld " TTYRPLD_VERSION "\n");
+        printf("This program comes with ABSOLUTELY NO WARRANTY; it is free "
+          "software\n" "and you are welcome to redistribute it under certain "
+          "conditions; for\n" "details see the COPYING file which should have "
+          "come with this program.\n"
         );
     }
 
@@ -176,9 +176,8 @@ static void mainloop(int fd) {
             break;
         }
 
-        PP_swab(&packet.dev, sizeof(packet.dev));
-        //PP_swab(&packet.dev2, sizeof(packet.dev2)); // .dev2 unused ATM
-        PP_swab(&packet.size, sizeof(packet.size));
+        SWAB(&packet.dev, sizeof(packet.dev));
+        SWAB(&packet.size, sizeof(packet.size));
 
         if(packet.magic != MAGIC_SIG) {
             ++Stats.badpack;
@@ -227,27 +226,6 @@ static int packet_preprox(struct mem_packet *packet) {
         [EVT_max]    = NULL,
     };
 
-    {
-        register long maj = K26_MAJOR(packet->dev);
-        if(maj == 128 /* Unix98 ptm (-) */) {
-            if(packet->event != EVT_DEINIT) {
-                /* All master side events (except EVT_DEINIT) are dropped,
-                since they are pty masters are an exact copy of their slaves,
-                so no need to record them too. */
-                return 0;
-            }
-
-            uint32_t tmp = packet->dev2;
-            packet->dev2 = packet->dev;
-            packet->dev  = tmp;
-        } else if(maj == 2 /* BSD ptm (/dev/ptypXY) */) {
-            /* Honestly, I am not sure whether BSD ptms also behave like Unix98
-            ptms above, but I assume it. So change major 2 to major 3. */
-            if(packet->event != EVT_DEINIT) { return 0; }
-            packet->dev = K26_MKDEV(K26_MAJOR(3), K26_MINOR(packet->dev));
-        }
-    }
-
     if(packet->event < EVT_max && tab[packet->event] != NULL) {
         ++*tab[packet->event];
     }
@@ -388,7 +366,7 @@ static int log_open(struct tty *tty) {
         buf[MAXFNLEN - 1] = '\0';
         strncpy(buf, "ttyrpld " TTYRPLD_VERSION, MAXFNLEN - 1);
         s = p.size = strlen(buf);
-        PP_swab(&p.size, sizeof(p.size));
+        SWAB(&p.size, sizeof(p.size));
         write(tty->fd, &p, sizeof(struct disk_packet));
         write(tty->fd, buf, s);
     }
@@ -406,9 +384,9 @@ static void log_write(struct mem_packet *packet, struct tty *tty, int fd) {
     if((have = read(fd, buffer, packet->size)) <= 0) { return; }
     if(have != packet->size) { packet->size = have; }
 
-    PP_swab(&packet->size, sizeof(packet->size));
-    PP_swab(&packet->tv.tv_sec, sizeof(packet->tv.tv_sec));
-    PP_swab(&packet->tv.tv_usec, sizeof(packet->tv.tv_usec));
+    SWAB(&packet->size, sizeof(packet->size));
+    SWAB(&packet->tv.tv_sec, sizeof(packet->tv.tv_sec));
+    SWAB(&packet->tv.tv_usec, sizeof(packet->tv.tv_usec));
     write(tty->fd, &packet->size, sizeof(struct disk_packet));
     write(tty->fd, buffer, have);
     return;
@@ -423,13 +401,13 @@ static int init_device(const char *in_devs) {
         if((fd = open(new_dev, O_RDONLY)) == -1) {
             int se = errno;
             new_dev = NULL;
-            perror("dynamic_find: Could not connect to RPL device");
+            perror("dynamic_find(): Could not open RPL device");
             if(se == EBUSY) {
                 fprintf(stderr, "\t" "The RPL device can only be opened once,"
                  "\n\t" "there is probably an instance of rpld running!\n");
             }
         } else if(GOpt.verbose) {
-            printf("Connected to RPL device\n");
+            printf("Successfully opened RPL device\n");
         }
         unlink(NODEPATH);
         unlink(new_dev);
@@ -446,13 +424,14 @@ static int init_device(const char *in_devs) {
                 break;
             }
             if(errno != ENOENT) {
-                fprintf(stderr, "static_find: Could not open %s even though "
-                 "it exists: %s (trying next device)\n",
+                fprintf(stderr, "static_find(): Could not open %s even"
+                 " though it exists: %s (trying next device)\n",
                  devp, strerror(errno));
             }
             if(errno == EBUSY) {
-                fprintf(stderr, "\t" "The RPL device can only be opened once,"
-                 "\n\t" "there is probably an instance of rpld running!\n");
+                fprintf(stderr, "\t" "The RPL device can only be opened"
+                 " once,\n\t" "there is probably an instance of rpld"
+                 " running!\n");
             }
             ++devp;
         }
@@ -495,7 +474,7 @@ static const char *mknod_rpldev(void) {
     if((fp = fopen("/sys/module/rpldev/Minor_nr", "r")) != NULL) {
         fgets(buf, sizeof(buf), fp);
         minor = strtol(buf, NULL, 0);
-    } else if((fp = fopen("/proc/misc", "r")) == NULL) {
+    } else if((fp = fopen("/proc/misc", "r")) != NULL) {
         while(fgets(buf, sizeof(buf), fp) != NULL) {
             char *ptr = buf, *name;
             while(!isdigit(*ptr)) { ++ptr; }
@@ -512,7 +491,6 @@ static const char *mknod_rpldev(void) {
     } else {
         fprintf(stderr, "Could not open either /sys/module/rpldev/Minor_nr "
          "or /proc/misc!\n");
-        fclose(fp);
         return NULL;
     }
 
@@ -552,7 +530,7 @@ static int init_sighandler(void) {
     /* All sigactions() shall be executed, however, if one fails, this function
     shall return <= 0, otherwise >0 upon success.
     Geesh, I love these constructs. */
-    return !(!!sigaction(SIGINT, &s_int, NULL) + 
+    return !(!!sigaction(SIGINT, &s_int, NULL) +
      !!sigaction(SIGTERM, &s_int, NULL) +
      !!sigaction(SIGALRM, &s_alrm, NULL) +
      !!sigaction(SIGPIPE, &s_pipe, NULL));
@@ -756,8 +734,8 @@ static uid_t getuidfromname(const char *name) {
     return ep->pw_uid;
 }
 
-static int value_cmp(void *pa, void *pb) {
-    return (pa > pb) - (pa < pb);
+inline static int value_cmp(void *pa, void *pb) {
+    return pa - pb;
 }
 
 //==[ End of file ]============================================================
